#!/bin/sh
# Exit the script if any command fails
set -e

if [ "$1" = 'start' ]; then

  if [ "$WEBCONTEXT" = '/' ]; then
      indexHtmlFilePath="/usr/share/nginx/html/index.html"
      ngswFilePath="/usr/share/nginx/html/ngsw.json"
      targetPath="/usr/share/nginx/html/assets/configurations"
  else
      mkdir -p /tmp/"$WEBCONTEXT"/
      mv -v /usr/share/nginx/html/* /tmp/"$WEBCONTEXT"/
      rm -rf /usr/share/nginx/html/*
      mkdir -p /usr/share/nginx/html/"$WEBCONTEXT"/
      mv -v /tmp/"$WEBCONTEXT"/* /usr/share/nginx/html/"$WEBCONTEXT"/
      rm -rf /tmp/"$WEBCONTEXT"
      indexHtmlFilePath="/usr/share/nginx/html/$WEBCONTEXT/index.html"
      ngswFilePath="/usr/share/nginx/html/$WEBCONTEXT/ngsw.json"
      targetPath="/usr/share/nginx/html/$WEBCONTEXT/assets/configurations"
  fi

  echo "File path index.html: '$indexHtmlFilePath'"
  echo "File path ngsw.json: '$ngswFilePath'"
  echo "File path configuration folder: '$targetPath'"

  sed -i -- 's/href="/href-temp="/g' "$indexHtmlFilePath"
  sed -i -- 's/src="/src-temp="/g' "$indexHtmlFilePath"

  echo "File 'index.html' updated by suffixing 'href' and 'src' with '-temp'"

  # Recompute new hash for index.html after edition for Service Worker
  sha1IndexFile=$(sha1sum $indexHtmlFilePath | awk '{print $1}')

  echo "New sha1 computed for file index.html: '$sha1IndexFile'"

  sed -i -- "s#\"/index.html\": \".*\"#\"/index.html\": \"$sha1IndexFile\"#g" "$ngswFilePath"

  echo "Entry '/index.html' hash updated in '$ngswFilePath' with new value '$sha1IndexFile'"

  jsonRuntimeFilePath="/usr/share/nginx/environments/environment.runtime.json"
  mkdir -p "$targetPath"

  # Inject environment config to the angular dist assets/ folder
  if [ -e $jsonRuntimeFilePath ]; then
    jq '.dummyClientSecret = $value' --arg value "$CLIENT_SECRET" $jsonRuntimeFilePath >/usr/share/nginx/environments/tmp.$$.json \
    && cp /usr/share/nginx/environments/tmp.$$.json "$targetPath/environment.runtime.json" \
    && rm -rf /usr/share/nginx/environments/tmp.$$.json
  fi

  # Start http server
  exec nginx -g 'daemon off;'
fi

# Used to run a custom command on container start
exec "$@"
